use crate::db::db::establish_connection;
use crate::models::models::{Comment, NewComment};
use crate::schema::comments;
use chrono::Utc;
use diesel::{alias, ExpressionMethods, JoinOnDsl, QueryDsl, RunQueryDsl, SelectableHelper, NullableExpressionMethods};
use crate::schema;

pub fn get_issue_comments(issue_id: i32) -> Vec<Comment> {
    let connection = &mut establish_connection();

    let (c1, c2) = alias!(comments as c1, comments as c2);

    comments::table
        .left_join(c1.on(comments::parent.eq(comments::id.nullable())))
        .filter(comments::issue_id.eq(issue_id))
        .select(Comment::as_select())
        .load::<Comment>(connection)
        .unwrap_or_else(|_| Vec::new())
}

pub fn create_comment(content: String, parent: Option<i64>, telegram_handle: String, issue_id: i32) -> Comment {
    let connection = &mut establish_connection();

    let new_comment = NewComment {
        content,
        parent,
        telegram_handle,
        issue_id,
        created_at: Utc::now().naive_utc()
    };
    let insertion = diesel::insert_into(comments::table)
        .values(&new_comment)
        .returning(Comment::as_select())
        .get_result(connection)
        .expect("Error saving comment");

    insertion
}